CodeMirror: merge view demo

## merge view demo

The `merge` addon provides an interface for displaying and merging diffs, either two-way or three-way. The left (or center) pane is editable, and the differences with the other pane(s) are optionally shown live as you edit it. In the two-way configuration, there are also options to pad changed sections to align them, and to collapse unchanged stretches of text.

This addon depends on the google-diff-match-patch library to compute the diffs.